@@ -1581,6 +1581,7 @@ extension VideoPlayerViewController: VLCPlaybackServiceDelegate {
             artWorkImageView.contentMode = .scaleAspectFit
             playbackService.videoOutputView = nil
         } else {
+            playbackService.videoOutputView = videoOutputView
             artWorkImageView.isHidden = true
             queueViewController?.reloadBackground(with: nil)
         }
@@ -1644,12 +1645,8 @@ extension VideoPlayerViewController: PlayerControllerDelegate {
 
 extension VideoPlayerViewController: MediaNavigationBarDelegate {
     func mediaNavigationBarDidTapClose(_ mediaNavigationBar: MediaNavigationBar) {
-        if playbackService.isPlaying {
-            delegate?.videoPlayerViewControllerDidMinimize(self)
-        } else {
-            playbackService.stopPlayback()
-            playbackService.setPlayAsAudio(false)
-        }
+        playbackService.stopPlayback()
+        playbackService.setPlayAsAudio(false)
     }
 
     func mediaNavigationBarDidToggleQueueView(_ mediaNavigationBar: MediaNavigationBar) {
@@ -1685,8 +1682,11 @@ extension VideoPlayerViewController: MediaNavigationBarDelegate {
     }
 
     func mediaNavigationBarDidCloseLongPress(_ mediaNavigationBar: MediaNavigationBar) {
-        playbackService.stopPlayback()
-        playbackService.setPlayAsAudio(false)
+        delegate?.videoPlayerViewControllerDidMinimize(self)
+    }
+
+    func mediaNavigationBarDisplayCloseAlert(_ mediaNavigationBar: MediaNavigationBar) {
+        statusLabel.showStatusMessage(NSLocalizedString("MINIMIZE_HINT", comment: ""))
     }
 }
 
